@@ -1,9 +1,7 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import os
 import sys
 import unittest
+
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 
